==> plainlog-0.1.1.tar.gz: plainlog-0.1.1/tests/test_bind.py <==
import pytest

from plainlog import logger, logger_core


def test_bind_after_add(writer):
    logger_core.add(writer)
    logger_bound = logger.bind(a=0)
    logger_bound.debug("A")
    logger_core.wait_for_processed()

    record = writer.first()

    assert record["extra"].get("a") == 0
    assert record["msg"] == "A"


def test_bind_before_add(writer):
    logger_bound = logger.bind(a=0)
    logger_core.add(writer)
    logger_bound.debug("A")
    logger_core.wait_for_processed()

    record = writer.first()

    assert record["extra"].get("a") == 0
    assert record["msg"] == "A"


def test_add_using_bound(writer):
    logger_core.configure(extra={"a": -1})
    logger_bound = logger.bind(a=0)
    logger_core.add(writer)
    logger.debug("A")
    logger_bound.debug("B")
    logger_core.wait_for_processed()

    record = writer.records[0]

    assert record["extra"].get("a") == -1
    assert record["msg"] == "A"
    
    record = writer.records[1]

    assert record["extra"].get("a") == 0
    assert record["msg"] == "B"


# def test_not_override_parent_logger(writer):
#     logger_1 = logger.bind(a="a")
#     logger_2 = logger_1.bind(a="A")
#     logger.add(writer, format="{extra[a]} {message}")

#     logger_1.debug("1")
#     logger_2.debug("2")

#     assert writer.read() == "a 1\nA 2\n"


# def test_override_previous_bound(writer):
#     logger.add(writer, format="{extra[x]} {message}")
#     logger.bind(x=1).bind(x=2).debug("3")
#     assert writer.read() == "2 3\n"


# def test_no_conflict(writer):
#     logger_ = logger.bind()
#     logger_2 = logger_.bind(a=2)
#     logger_3 = logger_.bind(a=3)

#     logger.add(writer, format="{extra[a]} {message}")

#     logger_2.debug("222")
#     logger_3.debug("333")

#     assert writer.read() == "2 222\n3 333\n"


# @pytest.mark.parametrize("using_bound", [True, False])
# def test_bind_and_add_level(writer, using_bound):
#     logger_bound = logger.bind()
#     logger.add(writer, format="{level.name} {message}")

#     if using_bound:
#         logger_bound.level("bar", 15)
#     else:
#         logger.level("bar", 15)

#     logger.log("bar", "root")
#     logger_bound.log("bar", "bound")

#     assert writer.read() == "bar root\nbar bound\n"


# def test_override_configured(writer):
#     logger.configure(extra={"a": 1})
#     logger2 = logger.bind(a=2)

#     logger2.add(writer, format="{extra[a]} {message}")

#     logger2.debug("?")

#     assert writer.read() == "2 ?\n"

==> plainlog-0.1.4.tar.gz: plainlog-0.1.4/tests/test_bind.py <==
import pytest

from plainlog import logger, logger_core


def test_bind_after_add(thandler):
    logger_bound = logger.bind(a=0)
    logger_bound.debug("A")

    record = thandler.first()

    assert record["extra"].get("a") == 0
    assert record["msg"] == "A"


def test_bind_before_add(thandler):
    logger_bound = logger.bind(a=0)
    logger_bound.debug("A")

    record = thandler.first()

    assert record["extra"].get("a") == 0
    assert record["msg"] == "A"


def test_add_using_bound(thandler):
    logger_core.configure(extra={"a": -1})
    logger_bound = logger.bind(a=0)
    logger.debug("A")
    logger_bound.debug("B")

    assert thandler.records

    record = thandler.records[0]

    assert record["extra"].get("a") == -1
    assert record["msg"] == "A"
    
    record = thandler.records[1]

    assert record["extra"].get("a") == 0
    assert record["msg"] == "B"


def test_unbind(thandler):
    lb = logger.bind(a=0)
    lb.debug("A")
    lb = lb.unbind("a")
    lb.debug("B")
    
    assert thandler.records
    record = thandler.records[0]
    assert record["extra"].get("a") == 0
    assert record["msg"] == "A"
    
    record = thandler.records[1]
    assert record["extra"].get("a") == None
    assert record["msg"] == "B"


# def test_not_override_parent_logger(writer):
#     logger_1 = logger.bind(a="a")
#     logger_2 = logger_1.bind(a="A")
#     logger.add(writer, format="{extra[a]} {message}")

#     logger_1.debug("1")
#     logger_2.debug("2")

#     assert writer.read() == "a 1\nA 2\n"


# def test_override_previous_bound(writer):
#     logger.add(writer, format="{extra[x]} {message}")
#     logger.bind(x=1).bind(x=2).debug("3")
#     assert writer.read() == "2 3\n"


# def test_no_conflict(writer):
#     logger_ = logger.bind()
#     logger_2 = logger_.bind(a=2)
#     logger_3 = logger_.bind(a=3)

#     logger.add(writer, format="{extra[a]} {message}")

#     logger_2.debug("222")
#     logger_3.debug("333")

#     assert writer.read() == "2 222\n3 333\n"


# @pytest.mark.parametrize("using_bound", [True, False])
# def test_bind_and_add_level(writer, using_bound):
#     logger_bound = logger.bind()
#     logger.add(writer, format="{level.name} {message}")

#     if using_bound:
#         logger_bound.level("bar", 15)
#     else:
#         logger.level("bar", 15)

#     logger.log("bar", "root")
#     logger_bound.log("bar", "bound")

#     assert writer.read() == "bar root\nbar bound\n"


# def test_override_configured(writer):
#     logger.configure(extra={"a": 1})
#     logger2 = logger.bind(a=2)

#     logger2.add(writer, format="{extra[a]} {message}")

#     logger2.debug("?")

#     assert writer.read() == "2 ?\n"
